Bivariate copula families
In this package several bivariate copula families are included for bivariate analysis as well as for multivariate analysis using vine copulas.
It provides functionality of elliptical (Gaussian and Student t) as well as Archimedean (Clayton, Gumbel, Frank, Joe, BB1 and BB7) copulas
to cover a large bandwidth of possible dependence structures.
For the one parameter Archimedean copula families rotated versions are included to cover negative dependence too.
The two parameter BB1 and BB7 copulas are however numerically instable for large parameters.
From experience we recommend that the respective first parameters are chosen smaller than 5 and the second parameters smaller than 6.
In general, the user should be careful with extreme parameter choices.
The following table shows the parameter ranges of bivariate copula families with parameters par and par2:
lll{
Copula family par par2
Gaussian $(-1,1)$ -
Student t $(-1,1)$ $(1,\infty)$
(Survival) Clayton $(0,\infty)$ -
(Survival) Gumbel $[1,\infty)$ -
Frank $R\backslash{0}$ -
(Survival) Joe $(1,\infty)$ -
Rotated Clayton (90 and 270 degrees) $(-\infty,0)$ -
Rotated Gumbel (90 and 270 degrees) $(-\infty,-1]$ -
Rotated Joe (90 and 270 degrees) $(-\infty,-1)$ -
Clayton-Gumbel (BB1) $(0,\infty)$ $[1,\infty)$
Joe-Clayton (BB7) $[1,\infty)$ $(0,\infty)$
}C- and D-vine copula models
When specifying C- and D-vine copula models, one has to select an order of the variables.
For a D-vine the order of the variables in the first tree has to be chosen and for a C-vine the root nodes for each tree need to be determined.
Functions for inference of C- and D-vine copula models in this package assume that the order of the variables in the data set under investigation
exactly corresponds to this C- or D-vine order.
E.g., in a C-vine the first column of a data set is the first root node, the second column the second root node, etc.
According to this order arguments have to be provided to functions for C- and D-vine copula inference.
After choosing the type of the vine model,
the copula families (family) and parameters (par and par2) have to be specified as vectors of length $d(d-1)/2$,
where $d$ is the number of variables.
In a C-vine, the entries of this vector correspond to the following pairs and associated pair-copula terms
$(1,2), (1,3), (1,4), ..., (1,d),$
$(2,3|1), (2,4|1), ..., (2,d|1),$
$(3,4|1,2), (3,5|1,2), ..., (3,d|1,2),$
$...,$
$(d-1,d|1,...,d-2).$
Similarly, the pairs of a D-vine are denoted in the following order:
$(1,2), (2,3), (3,4), ..., (d-1,d),$
$(1,3|2), (2,4|3), ..., (d-2,d|d-1),$
$(1,4|2,3), (2,5|3,4), ..., (d-3,d|d-2,d-1),$
$...,$
$(1,d|2,...,d-1).$Empirical Kendall's tau
We like to thank Shing (Eric) Fu, Feng Zhu, Guang (Jack) Yang, and Harry Joe for providing their implementation
of the method by Knight (1966) for efficiently computing the empirical Kendall's tau.